Fix some issues came up from the reviews of the newly added APIs
Test: Existing unit tests still pass.
BUG: 36554361
Change-Id: I6c2dab2e0df7f8578f92c70907f45aa69909892c
diff --git a/api/current.txt b/api/current.txt
index c490b17..f99f80d 100644
--- a/api/current.txt
+++ b/api/current.txt
@@ -20582,7 +20582,7 @@
method public double getAccumulatedDeltaRangeMeters();
method public int getAccumulatedDeltaRangeState();
method public double getAccumulatedDeltaRangeUncertaintyMeters();
- method public double getAutomaticGainControlLevelInDb();
+ method public double getAutomaticGainControlLevelDb();
method public long getCarrierCycles();
method public float getCarrierFrequencyHz();
method public double getCarrierPhase();
@@ -20598,7 +20598,7 @@
method public int getState();
method public int getSvid();
method public double getTimeOffsetNanos();
- method public boolean hasAutomaticGainControlLevelInDb();
+ method public boolean hasAutomaticGainControlLevelDb();
method public boolean hasCarrierCycles();
method public boolean hasCarrierFrequencyHz();
method public boolean hasCarrierPhase();
@@ -20692,7 +20692,7 @@
method public int getSatelliteCount();
method public int getSvid(int);
method public boolean hasAlmanacData(int);
- method public boolean hasCarrierFrequency(int);
+ method public boolean hasCarrierFrequencyHz(int);
method public boolean hasEphemerisData(int);
method public boolean usedInFix(int);
field public static final int CONSTELLATION_BEIDOU = 5; // 0x5
diff --git a/api/system-current.txt b/api/system-current.txt
index ed486b8..955cb13 100644
--- a/api/system-current.txt
+++ b/api/system-current.txt
@@ -22082,7 +22082,7 @@
method public double getAccumulatedDeltaRangeMeters();
method public int getAccumulatedDeltaRangeState();
method public double getAccumulatedDeltaRangeUncertaintyMeters();
- method public double getAutomaticGainControlLevelInDb();
+ method public double getAutomaticGainControlLevelDb();
method public long getCarrierCycles();
method public float getCarrierFrequencyHz();
method public double getCarrierPhase();
@@ -22098,7 +22098,7 @@
method public int getState();
method public int getSvid();
method public double getTimeOffsetNanos();
- method public boolean hasAutomaticGainControlLevelInDb();
+ method public boolean hasAutomaticGainControlLevelDb();
method public boolean hasCarrierCycles();
method public boolean hasCarrierFrequencyHz();
method public boolean hasCarrierPhase();
@@ -22192,7 +22192,7 @@
method public int getSatelliteCount();
method public int getSvid(int);
method public boolean hasAlmanacData(int);
- method public boolean hasCarrierFrequency(int);
+ method public boolean hasCarrierFrequencyHz(int);
method public boolean hasEphemerisData(int);
method public boolean usedInFix(int);
field public static final int CONSTELLATION_BEIDOU = 5; // 0x5
diff --git a/api/test-current.txt b/api/test-current.txt
index 35e5bfc..40c6f01 100644
--- a/api/test-current.txt
+++ b/api/test-current.txt
@@ -20659,7 +20659,7 @@
method public double getAccumulatedDeltaRangeMeters();
method public int getAccumulatedDeltaRangeState();
method public double getAccumulatedDeltaRangeUncertaintyMeters();
- method public double getAutomaticGainControlLevelInDb();
+ method public double getAutomaticGainControlLevelDb();
method public long getCarrierCycles();
method public float getCarrierFrequencyHz();
method public double getCarrierPhase();
@@ -20675,7 +20675,7 @@
method public int getState();
method public int getSvid();
method public double getTimeOffsetNanos();
- method public boolean hasAutomaticGainControlLevelInDb();
+ method public boolean hasAutomaticGainControlLevelDb();
method public boolean hasCarrierCycles();
method public boolean hasCarrierFrequencyHz();
method public boolean hasCarrierPhase();
@@ -20806,7 +20806,7 @@
method public int getSatelliteCount();
method public int getSvid(int);
method public boolean hasAlmanacData(int);
- method public boolean hasCarrierFrequency(int);
+ method public boolean hasCarrierFrequencyHz(int);
method public boolean hasEphemerisData(int);
method public boolean usedInFix(int);
field public static final int CONSTELLATION_BEIDOU = 5; // 0x5
diff --git a/location/java/android/location/GnssMeasurement.java b/location/java/android/location/GnssMeasurement.java
index aac9727..de85c16 100644
--- a/location/java/android/location/GnssMeasurement.java
+++ b/location/java/android/location/GnssMeasurement.java
@@ -670,6 +670,8 @@
* related to L5 will be filled.
*
* <p>The value is only available if {@link #hasCarrierFrequencyHz()} is {@code true}.
+ *
+ * @return the carrier frequency of the signal tracked in Hz.
*/
public float getCarrierFrequencyHz() {
return mCarrierFrequencyHz;
@@ -888,10 +890,10 @@
}
/**
* Returns {@code true} if {@link #getAutomaticGainControlLevelInDb()} is available,
* {@code false} otherwise.
*/
- public boolean hasAutomaticGainControlLevelInDb() {
+ public boolean hasAutomaticGainControlLevelDb() {
return isFlagSet(HAS_AUTOMATIC_GAIN_CONTROL);
}
@@ -908,9 +910,9 @@
* components) may also affect the typical output of of this value on any given hardware design
* in an open sky test - the important aspect of this output is that changes in this value are
* indicative of changes on input signal power in the frequency band for this measurement.
- * <p>The value is only available if {@link #hasAutomaticGainControlLevelInDb()} is {@code true}
+ * <p>The value is only available if {@link #hasAutomaticGainControlLevelDb()} is {@code true}
*/
- public double getAutomaticGainControlLevelInDb() {
+ public double getAutomaticGainControlLevelDb() {
return mAutomaticGainControlLevelInDb;
}
@@ -1064,7 +1066,7 @@
builder.append(String.format(
format,
"AgcLevelDb",
- hasAutomaticGainControlLevelInDb() ? mAutomaticGainControlLevelInDb : null));
+ hasAutomaticGainControlLevelDb() ? mAutomaticGainControlLevelInDb : null));
return builder.toString();
}
@@ -888,10 +890,10 @@
}
/**
- * Returns {@code true} if {@link #getAutomaticGainControlLevelInDb()} is available,
+ * Returns {@code true} if {@link #getAutomaticGainControlLevelDb()} is available,
* {@code false} otherwise.
*/
diff --git a/location/java/android/location/GnssStatus.java b/location/java/android/location/GnssStatus.java
index e90a174..a44bc5b 100644
--- a/location/java/android/location/GnssStatus.java
+++ b/location/java/android/location/GnssStatus.java
@@ -224,7 +224,7 @@
*
* @param satIndex the index of the satellite in the list.
*/
- public boolean hasCarrierFrequency(int satIndex) {
+ public boolean hasCarrierFrequencyHz(int satIndex) {
return (mSvidWithFlags[satIndex] & GNSS_SV_FLAGS_HAS_CARRIER_FREQUENCY) != 0;
}
@@ -239,7 +239,11 @@
* will be reported for this same satellite, in one all the values related to L1 will be filled,
* and in the other all of the values related to L5 will be filled.
*
* <p>The value is only available if {@link #hasCarrierFrequency(int satIndex)} is {@code true}.
*/
public float getCarrierFrequencyHz(int satIndex) {
return mCarrierFrequencies[satIndex];
@@ -239,7 +239,11 @@
* and in the other all of the values related to L5 will be filled.
*
- * <p>The value is only available if {@link #hasCarrierFrequency(int satIndex)} is {@code true}.
+ * <p>The value is only available if {@link #hasCarrierFrequencyHz(int satIndex)} is {@code true}.
+ *
+ * @param satIndex the index of the satellite in the list.
+ *
+ * @return the carrier frequency of the signal tracked in Hz.
*/
public float getCarrierFrequencyHz(int satIndex) {